#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXPM1_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXPM1_HPP_INCLUDED

#include <nt2/exponential/include/functions/scalar/expm1.hpp>

#endif
